==> XFree86-4.4.0-src-1.tgz: xc/lib/Xt/Xt-def.cpp <==
LIBRARY Xt
VERSION LIBRARY_VERSION
EXPORTS
 applicationShellClassRec DATA
 applicationShellWidgetClass DATA
 compositeClassRec DATA
 compositeWidgetClass DATA
 constraintClassRec DATA
 constraintWidgetClass DATA
 coreWidgetClass DATA
 hookObjClassRec DATA
 hookObjectClass DATA
 objectClass DATA
 objectClassRec DATA
 overrideShellClassRec DATA
 overrideShellWidgetClass DATA
 rectObjClass DATA
 rectObjClassRec DATA
 screenConvertArg DATA
 sessionShellClassRec DATA
 sessionShellWidgetClass DATA
 shellClassRec DATA
 shellWidgetClass DATA
 topLevelShellClassRec DATA
 topLevelShellWidgetClass DATA
 transientShellClassRec DATA
 transientShellWidgetClass DATA
 vendorShellClassRec DATA
 vendorShellWidgetClass DATA
 widgetClass DATA
 widgetClassRec DATA
 wmShellClassRec DATA
 wmShellWidgetClass DATA
 _XtCheckSubclassFlag
 _XtCopyFromArg
 _XtInherit
 _XtInheritTranslations
 _XtIsSubclassOf
 XtAddActions
 XtAddCallback
 XtAddCallbacks
 XtAddConverter
 XtAddEventHandler
 XtAddExposureToRegion
 XtAddGrab
 XtAddInput
 XtAddRawEventHandler
 XtAddSignal
 XtAddTimeOut
 XtAddWorkProc
 XtAllocateGC
 XtAppAddActionHook
 XtAppAddActions
 XtAppAddBlockHook
 XtAppAddConverter
 XtAppAddInput
 XtAppAddSignal
 XtAppAddTimeOut
 XtAppAddWorkProc
 XtAppCreateShell
 XtAppError
 XtAppErrorMsg
 XtAppGetErrorDatabase
 XtAppGetErrorDatabaseText
 XtAppGetExitFlag
 XtAppGetSelectionTimeout
 XtAppInitialize
 XtAppLock
 XtAppMainLoop
 XtAppNextEvent
 XtAppPeekEvent
 XtAppPending
 XtAppProcessEvent
 XtAppReleaseCacheRefs
 XtAppSetErrorHandler
 XtAppSetErrorMsgHandler
 XtAppSetExitFlag
 XtAppSetFallbackResources
 XtAppSetSelectionTimeout
 XtAppSetTypeConverter
 XtAppSetWarningHandler
 XtAppSetWarningMsgHandler
 XtAppUnlock
 XtAppWarning
 XtAppWarningMsg
 XtAugmentTranslations
 XtBuildEventMask
 XtCallAcceptFocus
 XtCallActionProc
 XtCallbackExclusive
 XtCallbackNone
 XtCallbackNonexclusive
 XtCallbackPopdown
 XtCallbackReleaseCacheRef
 XtCallbackReleaseCacheRefList
 XtCallCallbackList
 XtCallCallbacks
 XtCallConverter
 XtCalloc
 XtCancelSelectionRequest
 XtChangeManagedSet
 XtClass
 XtCloseDisplay
 XtConfigureWidget
 XtConvert
 XtConvertAndStore
 XtConvertCase
 XtCreateApplicationContext
 XtCreateApplicationShell
 XtCreateManagedWidget
 XtCreatePopupShell
 XtCreateSelectionRequest
 XtCreateWidget
 XtCreateWindow
 XtCvtColorToPixel
 XtCvtIntToBool
 XtCvtIntToBoolean
 XtCvtIntToColor
 XtCvtIntToFloat
 XtCvtIntToFont
 XtCvtIntToPixel
 XtCvtIntToPixmap
 XtCvtIntToShort
 XtCvtIntToUnsignedChar
 XtCvtStringToAcceleratorTable
 XtCvtStringToAtom
 XtCvtStringToBool
 XtCvtStringToBoolean
 XtCvtStringToCommandArgArray
 XtCvtStringToCursor
 XtCvtStringToDimension
 XtCvtStringToDirectoryString
 XtCvtStringToDisplay
 XtCvtStringToFile
 XtCvtStringToFloat
 XtCvtStringToFont
 XtCvtStringToFontSet
 XtCvtStringToFontStruct
 XtCvtStringToGravity
 XtCvtStringToInitialState
 XtCvtStringToInt
 XtCvtStringToPixel
 XtCvtStringToRestartStyle
 XtCvtStringToShort
 XtCvtStringToTranslationTable
 XtCvtStringToUnsignedChar
 XtCvtStringToVisual
 XtCXtToolkitError
 XtDatabase
 XtDestroyApplicationContext
 XtDestroyGC
 XtDestroyWidget
 XtDirectConvert
 XtDisownSelection
 XtDispatchEvent
 XtDispatchEventToWidget
 XtDisplay
 XtDisplayInitialize
 XtDisplayOfObject
 XtDisplayStringConversionWarning
 XtDisplayToApplicationContext
 XtError
 XtErrorMsg
 XtFindFile
 XtFree
 XtGetActionKeysym
 XtGetActionList
 XtGetApplicationNameAndClass
 XtGetApplicationResources
 XtGetClassExtension
 XtGetConstraintResourceList
 XtGetDisplays
 XtGetErrorDatabase
 XtGetErrorDatabaseText
 XtGetGC
 XtGetKeyboardFocusWidget
 XtGetKeysymTable
 XtGetMultiClickTime
 XtGetResourceList
 XtGetSelectionParameters
 XtGetSelectionRequest
 XtGetSelectionTimeout
 XtGetSelectionValue
 XtGetSelectionValueIncremental
 XtGetSelectionValues
 XtGetSelectionValuesIncremental
 XtGetSubresources
 XtGetSubvalues
 XtGetValues
 XtGrabButton
 XtGrabKey
 XtGrabKeyboard
 XtGrabPointer
 XtHasCallbacks
 XtHooksOfDisplay
 XtInitialize
 XtInitializeWidgetClass
 XtInsertEventHandler
 XtInsertEventTypeHandler
 XtInsertRawEventHandler
 XtInstallAccelerators
 XtInstallAllAccelerators
 XtIsApplicationShell
 XtIsComposite
 XtIsConstraint
 XtIsManaged
 XtIsObject
 XtIsOverrideShell
 XtIsRealized
 XtIsRectObj
 XtIsSensitive
 XtIsSessionShell
 XtIsShell
 XtIsSubclass
 XtIsTopLevelShell
 XtIsTransientShell
 XtIsVendorShell
 XtIsWidget
 XtIsWMShell
 XtKeysymToKeycodeList
 XtLastEventProcessed
 XtLastTimestampProcessed
 XtMainLoop
 XtMakeGeometryRequest
 XtMakeResizeRequest
 XtMalloc
 XtManageChild
 XtManageChildren
 XtMapWidget
 XtMenuPopupAction
 XtMergeArgLists
 XtMoveWidget
 XtName
 XtNameToWidget
 XtNewString
 XtNextEvent
 XtNoticeSignal
 XtOpenApplication
 XtOpenDisplay
 XtOverrideTranslations
 XtOwnSelection
 XtOwnSelectionIncremental
 XtParent
 XtParseAcceleratorTable
 XtParseTranslationTable
 XtPeekEvent
 XtPending
 XtPopdown
 XtPopup
 XtPopupSpringLoaded
 XtProcessEvent
 XtProcessLock
 XtProcessUnlock
 XtQueryGeometry
 XtRealizeWidget
 XtRealloc
 XtRegisterCaseConverter
 XtRegisterDrawable
 XtRegisterExtensionSelector
 XtRegisterGrabAction
 XtReleaseGC
 XtReleasePropertyAtom
 XtRemoveActionHook
 XtRemoveAllCallbacks
 XtRemoveBlockHook
 XtRemoveCallback
 XtRemoveCallbacks
 XtRemoveEventHandler
 XtRemoveEventTypeHandler
 XtRemoveGrab
 XtRemoveInput
 XtRemoveRawEventHandler
 XtRemoveSignal
 XtRemoveTimeOut
 XtRemoveWorkProc
 XtReservePropertyAtom
 XtResizeWidget
 XtResizeWindow
 XtResolvePathname
 XtScreen
 XtScreenDatabase
 XtScreenOfObject
 XtSendSelectionRequest
 XtSessionGetToken
 XtSessionReturnToken
 XtSetErrorHandler
 XtSetErrorMsgHandler
 XtSetEventDispatcher
 XtSetKeyboardFocus
 XtSetKeyTranslator
 XtSetLanguageProc
 XtSetMappedWhenManaged
 XtSetMultiClickTime
 XtSetSelectionParameters
 XtSetSelectionTimeout
 XtSetSensitive
 XtSetSubvalues
 XtSetTypeConverter
 XtSetValues
 XtSetWarningHandler
 XtSetWarningMsgHandler
 XtSetWMColormapWindows
 XtShellStrings
 XtStringConversionWarning
 XtStrings
 XtSuperclass
 XtToolkitInitialize
 XtToolkitThreadInitialize
 XtTranslateCoords
 XtTranslateKey
 XtTranslateKeycode
 XtUngrabButton
 XtUngrabKey
 XtUngrabKeyboard
 XtUngrabPointer
 XtUninstallTranslations
 XtUnmanageChild
 XtUnmanageChildren
 XtUnmapWidget
 XtUnrealizeWidget
 XtUnregisterDrawable
 XtVaAppCreateShell
 XtVaAppInitialize
 XtVaCreateArgsList
 XtVaCreateManagedWidget
 XtVaCreatePopupShell
 XtVaCreateWidget
 XtVaGetApplicationResources
 XtVaGetSubresources
 XtVaGetSubvalues
 XtVaGetValues
 XtVaOpenApplication
 XtVaSetSubvalues
 XtVaSetValues
 XtWarning
 XtWarningMsg
 XtWidgetToApplicationContext
 XtWindow
 XtWindowOfObject
 XtWindowToWidget
 _XtWaitForSomething
#ifdef __UNIXOS2__
 _XtAddCallback
 _XtRemoveCallback
 _XtRemoveAllCallbacks
 _XtPrintXlations
 _XtAllocError
 _XtCountVaList
 _XtVaToArgList
#endif
/* $Xorg: Xt-def.cpp,v 1.3 2000/08/17 19:46:20 cpqbld Exp $ */
/* $XFree86: xc/lib/Xt/Xt-def.cpp,v 1.4 2003/11/06 03:25:41 dawes Exp $ */

==> XFree86-4.8.0-src-1.tgz: xc/lib/Xt/Xt-def.cpp <==
LIBRARY Xt
VERSION LIBRARY_VERSION
EXPORTS
 applicationShellClassRec DATA
 applicationShellWidgetClass DATA
 compositeClassRec DATA
 compositeWidgetClass DATA
 constraintClassRec DATA
 constraintWidgetClass DATA
 coreWidgetClass DATA
 colorConvertArgs DATA
 hookObjClassRec DATA
 hookObjectClass DATA
 objectClass DATA
 objectClassRec DATA
 overrideShellClassRec DATA
 overrideShellWidgetClass DATA
 rectObjClass DATA
 rectObjClassRec DATA
 screenConvertArg DATA
 sessionShellClassRec DATA
 sessionShellWidgetClass DATA
 shellClassRec DATA
 shellWidgetClass DATA
 topLevelShellClassRec DATA
 topLevelShellWidgetClass DATA
 transientShellClassRec DATA
 transientShellWidgetClass DATA
 vendorShellClassRec DATA
 vendorShellWidgetClass DATA
 widgetClass DATA
 widgetClassRec DATA
 wmShellClassRec DATA
 wmShellWidgetClass DATA
 _XtAddCallback
 _XtAllocError
 _XtCheckSubclassFlag
 _XtCopyFromArg
 _XtCountVaList
 _XtInherit
 _XtInheritTranslations
 _XtIsSubclassOf
 _XtPrintXlations
 _XtRemoveAllCallbacks
 _XtRemoveCallback
 _XtVaToArgList
 _XtWaitForSomething
 XtAddActions
 XtAddCallback
 XtAddCallbacks
 XtAddConverter
 XtAddEventHandler
 XtAddExposureToRegion
 XtAddGrab
 XtAddInput
 XtAddRawEventHandler
 XtAddSignal
 XtAddTimeOut
 XtAddWorkProc
 XtAllocateGC
 XtAppAddActionHook
 XtAppAddActions
 XtAppAddBlockHook
 XtAppAddConverter
 XtAppAddInput
 XtAppAddSignal
 XtAppAddTimeOut
 XtAppAddWorkProc
 XtAppCreateShell
 XtAppError
 XtAppErrorMsg
 XtAppGetErrorDatabase
 XtAppGetErrorDatabaseText
 XtAppGetExitFlag
 XtAppGetSelectionTimeout
 XtAppInitialize
 XtAppLock
 XtAppMainLoop
 XtAppNextEvent
 XtAppPeekEvent
 XtAppPending
 XtAppProcessEvent
 XtAppReleaseCacheRefs
 XtAppSetErrorHandler
 XtAppSetErrorMsgHandler
 XtAppSetExitFlag
 XtAppSetFallbackResources
 XtAppSetSelectionTimeout
 XtAppSetTypeConverter
 XtAppSetWarningHandler
 XtAppSetWarningMsgHandler
 XtAppUnlock
 XtAppWarning
 XtAppWarningMsg
 XtAugmentTranslations
 XtBuildEventMask
 XtCallAcceptFocus
 XtCallActionProc
 XtCallbackExclusive
 XtCallbackNone
 XtCallbackNonexclusive
 XtCallbackPopdown
 XtCallbackReleaseCacheRef
 XtCallbackReleaseCacheRefList
 XtCallCallbackList
 XtCallCallbacks
 XtCallConverter
 XtCalloc
 XtCancelSelectionRequest
 XtChangeManagedSet
 XtClass
 XtCloseDisplay
 XtConfigureWidget
 XtConvert
 XtConvertAndStore
 XtConvertCase
 XtCreateApplicationContext
 XtCreateApplicationShell
 XtCreateManagedWidget
 XtCreatePopupShell
 XtCreateSelectionRequest
 XtCreateWidget
 XtCreateWindow
 XtCvtColorToPixel
 XtCvtIntToBool
 XtCvtIntToBoolean
 XtCvtIntToColor
 XtCvtIntToFloat
 XtCvtIntToFont
 XtCvtIntToPixel
 XtCvtIntToPixmap
 XtCvtIntToShort
 XtCvtIntToUnsignedChar
 XtCvtStringToAcceleratorTable
 XtCvtStringToAtom
 XtCvtStringToBool
 XtCvtStringToBoolean
 XtCvtStringToCommandArgArray
 XtCvtStringToCursor
 XtCvtStringToDimension
 XtCvtStringToDirectoryString
 XtCvtStringToDisplay
 XtCvtStringToFile
 XtCvtStringToFloat
 XtCvtStringToFont
 XtCvtStringToFontSet
 XtCvtStringToFontStruct
 XtCvtStringToGravity
 XtCvtStringToInitialState
 XtCvtStringToInt
 XtCvtStringToPixel
 XtCvtStringToRestartStyle
 XtCvtStringToShort
 XtCvtStringToTranslationTable
 XtCvtStringToUnsignedChar
 XtCvtStringToVisual
 XtCXtToolkitError
 XtDatabase
 XtDestroyApplicationContext
 XtDestroyGC
 XtDestroyWidget
 XtDirectConvert
 XtDisownSelection
 XtDispatchEvent
 XtDispatchEventToWidget
 XtDisplay
 XtDisplayInitialize
 XtDisplayOfObject
 XtDisplayStringConversionWarning
 XtDisplayToApplicationContext
 XtError
 XtErrorMsg
 XtFindFile
 XtFree
 XtGetActionKeysym
 XtGetActionList
 XtGetApplicationNameAndClass
 XtGetApplicationResources
 XtGetClassExtension
 XtGetConstraintResourceList
 XtGetDisplays
 XtGetErrorDatabase
 XtGetErrorDatabaseText
 XtGetGC
 XtGetKeyboardFocusWidget
 XtGetKeysymTable
 XtGetMultiClickTime
 XtGetResourceList
 XtGetSelectionParameters
 XtGetSelectionRequest
 XtGetSelectionTimeout
 XtGetSelectionValue
 XtGetSelectionValueIncremental
 XtGetSelectionValues
 XtGetSelectionValuesIncremental
 XtGetSubresources
 XtGetSubvalues
 XtGetValues
 XtGrabButton
 XtGrabKey
 XtGrabKeyboard
 XtGrabPointer
 XtHasCallbacks
 XtHooksOfDisplay
 XtInitialize
 XtInitializeWidgetClass
 XtInsertEventHandler
 XtInsertEventTypeHandler
 XtInsertRawEventHandler
 XtInstallAccelerators
 XtInstallAllAccelerators
 XtIsApplicationShell
 XtIsComposite
 XtIsConstraint
 XtIsManaged
 XtIsObject
 XtIsOverrideShell
 XtIsRealized
 XtIsRectObj
 XtIsSensitive
 XtIsSessionShell
 XtIsShell
 XtIsSubclass
 XtIsTopLevelShell
 XtIsTransientShell
 XtIsVendorShell
 XtIsWidget
 XtIsWMShell
 XtKeysymToKeycodeList
 XtLastEventProcessed
 XtLastTimestampProcessed
 XtMainLoop
 XtMakeGeometryRequest
 XtMakeResizeRequest
 XtMalloc
 XtManageChild
 XtManageChildren
 XtMapWidget
 XtMenuPopupAction
 XtMergeArgLists
 XtMoveWidget
 XtName
 XtNameToWidget
 XtNewString
 XtNewStringEx
 XtStringLengthEx
 XtCharIndexEx
 XtNextEvent
 XtNoticeSignal
 XtOpenApplication
 XtOpenDisplay
 XtOverrideTranslations
 XtOwnSelection
 XtOwnSelectionIncremental
 XtParent
 XtParseAcceleratorTable
 XtParseTranslationTable
 XtPeekEvent
 XtPending
 XtPopdown
 XtPopup
 XtPopupSpringLoaded
 XtProcessEvent
 XtProcessLock
 XtProcessUnlock
 XtQueryGeometry
 XtRealizeWidget
 XtRealloc
 XtRegisterCaseConverter
 XtRegisterDrawable
 XtRegisterExtensionSelector
 XtRegisterGrabAction
 XtReleaseGC
 XtReleasePropertyAtom
 XtRemoveActionHook
 XtRemoveAllCallbacks
 XtRemoveBlockHook
 XtRemoveCallback
 XtRemoveCallbacks
 XtRemoveEventHandler
 XtRemoveEventTypeHandler
 XtRemoveGrab
 XtRemoveInput
 XtRemoveRawEventHandler
 XtRemoveSignal
 XtRemoveTimeOut
 XtRemoveWorkProc
 XtReservePropertyAtom
 XtResizeWidget
 XtResizeWindow
 XtResolvePathname
 XtScreen
 XtScreenDatabase
 XtScreenOfObject
 XtSendSelectionRequest
 XtSessionGetToken
 XtSessionReturnToken
 XtSetErrorHandler
 XtSetErrorMsgHandler
 XtSetEventDispatcher
 XtSetKeyboardFocus
 XtSetKeyTranslator
 XtSetLanguageProc
 XtSetMappedWhenManaged
 XtSetMultiClickTime
 XtSetSelectionParameters
 XtSetSelectionTimeout
 XtSetSensitive
 XtSetSubvalues
 XtSetTypeConverter
 XtSetValues
 XtSetWarningHandler
 XtSetWarningMsgHandler
 XtSetWMColormapWindows
 XtShellStrings
 XtStringConversionWarning
 XtStrings
 XtSuperclass
 XtToolkitInitialize
 XtToolkitThreadInitialize
 XtTranslateCoords
 XtTranslateKey
 XtTranslateKeycode
 XtUngrabButton
 XtUngrabKey
 XtUngrabKeyboard
 XtUngrabPointer
 XtUninstallTranslations
 XtUnmanageChild
 XtUnmanageChildren
 XtUnmapWidget
 XtUnrealizeWidget
 XtUnregisterDrawable
 XtVaAppCreateShell
 XtVaAppInitialize
 XtVaCreateArgsList
 XtVaCreateManagedWidget
 XtVaCreatePopupShell
 XtVaCreateWidget
 XtVaGetApplicationResources
 XtVaGetSubresources
 XtVaGetSubvalues
 XtVaGetValues
 XtVaOpenApplication
 XtVaSetSubvalues
 XtVaSetValues
 XtWarning
 XtWarningMsg
 XtWidgetToApplicationContext
 XtWindow
 XtWindowOfObject
 XtWindowToWidget
/* $XFree86: xc/lib/Xt/Xt-def.cpp,v 1.7 2006/01/25 04:32:09 dawes Exp $ */
